<?php
require_once(__DIR__ . '/../inc/config.php');
require_once(__DIR__ . '/_admin_inc.php'); // checks session and user id; die() if not admin
require_once(__DIR__ . '/../translations/admin_translations/trans-listings.php');

// path info
$frags = '';
if(!empty($_SERVER['PATH_INFO'])) {
	$frags = $_SERVER['PATH_INFO'];
}
else {
	if(!empty($_SERVER['ORIG_PATH_INFO'])) {
		$frags = $_SERVER['ORIG_PATH_INFO'];
	}
}
$frags = explode("/", $frags);

// paging vars
$page = !empty($frags[3]) ? $frags[3] : 1;
$limit = $items_per_page;
if($page > 1) {
	$offset = ($page-1) * $limit + 1;
}
else {
	$offset = 1;
}

// sort order
$sort = !empty($frags[1]) ? $frags[1] : 'sort-date';

// get listings
// count how many
$query = "SELECT COUNT(*) AS total_rows FROM places WHERE status <> 'trashed'";
$stmt = $conn->prepare($query);
$stmt->execute();
$row = $stmt->fetch(PDO::FETCH_ASSOC);
$total_rows = $row['total_rows'];

if($total_rows > 0) {
	$pager = new BusinessDirectory\PageIterator($limit, $total_rows, $page);
	$start = $pager->getStartRow();

	// sort, order by
	$orderby = "p.place_name";
	$where = "WHERE status <> 'trashed'";

	if($sort == 'sort-date') {
		$orderby = "p.place_id DESC";
	}

	if($sort == 'sort-name') {
		$orderby = "p.place_name";
	}

	if($sort == 'find') {
		$orderby = "p.place_name";
		$where = "WHERE p.place_id = " . (int)$frags[2];

		// first count
		$query = "SELECT COUNT(*) AS total_rows FROM places WHERE place_id = " . (int)$frags[2];
		$stmt = $conn->prepare($query);
		$stmt->execute();
		$row = $stmt->fetch(PDO::FETCH_ASSOC);
		$total_rows = $row['total_rows'];
	}

	// the query
	$query = "SELECT
			p.place_id, p.place_name, p.submission_date, p.feat_home, p.status, p.paid,
			c.city_name, c.slug, c.state,
			rel.cat_id,
			cats.name AS cat_name
		FROM places p
			LEFT JOIN cities c ON p.city_id = c.city_id
			LEFT JOIN rel_place_cat rel ON rel.place_id = p.place_id
			LEFT JOIN cats ON rel.cat_id = cats.id
		$where
		GROUP BY p.place_id
		ORDER BY $orderby LIMIT :start, :limit";
	$stmt = $conn->prepare($query);
	$stmt->bindValue(':start', $start);
	$stmt->bindValue(':limit', $limit);
	$stmt->execute();

	$places_arr = array();
	while($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
		$place_id        = $row['place_id'];
		$place_name      = $row['place_name'];
		$city_name       = $row['city_name'];
		$city_slug       = $row['slug'];
		$state_abbr      = $row['state'];
		$cat_name        = $row['cat_name'];
		$submission_date = $row['submission_date'];
		$feat_home       = $row['feat_home'];
		$status          = $row['status'];
		$paid            = $row['paid'];

		// sanitize
		$place_name = e($place_name);
		$place_slug = to_slug($place_name);

		// simplify date
		$submission_date = strtotime($submission_date);
		$date_formatted  = date( 'Y-m-d', $submission_date );

		// link to each place
		$link_url = $baseurl . '/' . $city_slug . '/place/' . $place_id . '/' . $place_slug;

		$cur_loop_arr = array(
			'place_id'       => $place_id,
			'place_name'     => $place_name,
			'place_slug'     => $place_slug,
			'link_url'       => $link_url,
			'city_name'      => $city_name,
			'city_slug'      => $city_slug,
			'state_abbr'     => $state_abbr,
			'cat_name'       => $cat_name,
			'date_formatted' => $date_formatted,
			'feat_home'      => $feat_home,
			'status'         => $status,
			'paid'           => $paid
		);

		$places_arr[] = $cur_loop_arr;
	}
}
?>
<!DOCTYPE html>
<!--[if IE 9]><html class="lt-ie10" lang="<?= $html_lang; ?>" > <![endif]-->
<html lang="<?= $html_lang; ?>" >
<head>
<title><?= $txt_html_title; ?> - <?= $site_name; ?></title>
<?php require_once(__DIR__ . '/_admin_html_head.php'); ?>
<style>
.editable-container.editable-inline {
	width: 100%;
}

@media only screen and (min-width: 768px) {
	.form-inline .form-control {
		width: 100%;
	}
}

.control-group.form-group {
	width: 100%;
}

.editable-input {
	width: 80%;
}

.x-editable-textarea {
	width: 600px;
}

.editable-click, a.editable-click, a.editable-click:hover {
	text-decoration: none;
	border-bottom: 0;
}
</style>
</head>
<body class="admin-listings">
<?php require_once(__DIR__ . '/_admin_header.php'); ?>

<div class="wrapper">
	<div class="menu-box">
		<?php require_once(__DIR__ . '/_admin_menu.php'); ?>
	</div>

	<div class="main-container">
		<h2><?= $txt_main_title; ?></h2>

		<div class="padding">
			<form class="form-search-place">
				<div class="block">
					<label class="label" for="place_id"><?= $txt_find_by_id; ?></label><br>
					<?= $txt_find_by_id_explain; ?><br>
					<input type="number" id="place_id" name="place_id" class="form-control width-25" required>
					<button type="button" id="submit_place_id" name="submit_place_id" class="btn btn-blue btn-less-padding btn-form-control" style="padding: 4px 8px;"><?= $txt_find; ?></button>
				</div>
			</form>

			<div class="block">
				<strong><?= $txt_sort; ?>:</strong><br>
				<a href="<?= $baseurl; ?>/admin/admin-listings/sort-name/" class="btn btn-default btn-less-padding"><?= $txt_by_name; ?></a>
				<a href="<?= $baseurl; ?>/admin/admin-listings" class="btn btn-default btn-less-padding"><?= $txt_by_date; ?></a>
			</div>

			<?php
			if($total_rows > 0) {
				?>
				<span><?= $txt_total_rows; ?>: <strong><?= $total_rows; ?></strong></span>
				<div class="table-responsive">
					<table class="table admin-table table-striped">
						<tr>
							<th><?= $txt_id; ?></th>
							<th><?= $txt_place_name; ?></th>
							<th><?= $txt_city; ?></th>
							<th><?= $txt_cat; ?></th>
							<th><?= $txt_date; ?></th>
							<th><?= $txt_action; ?></th>
						</tr>
						<?php
						foreach($places_arr as $k => $v) {
							$place_id       = $v['place_id'];
							$place_name     = $v['place_name'];
							$place_slug     = $v['place_slug'];
							$link_url       = $v['link_url'];
							$city_name      = $v['city_name'];
							$city_slug      = $v['city_slug'];
							$state_abbr     = $v['state_abbr'];
							$cat_name       = $v['cat_name'];
							$date_formatted = $v['date_formatted'];
							$feat_home      = $v['feat_home'];
							$status         = $v['status'];
							$paid           = $v['paid'];
							?>
							<tr id="tr-place-id=<?= $place_id; ?>">
								<td><?= $place_id; ?></td>
								<td><a href="<?= $link_url; ?>" target="_blank"><?= $place_name; ?></a></td>
								<td class="nowrap">
									<?php
									if(!empty($city_name)) {
										?>
										<?= $city_name; ?>, <?= $state_abbr; ?>
									<?php
									}
									?>
								</td>
								<td class="nowrap"><?= $cat_name; ?></td>
								<td class="nowrap"><?= $date_formatted; ?></td>
								<td class="nowrap">
									<!-- status btn -->
									<?php
									if($status == 'pending') {
										?>
										<span data-toggle="tooltip"	title="<?= $txt_toggle_approved; ?>">
											<a href="#" class="btn btn-default btn-less-padding approve-place"
												id="status-place-<?= $place_id; ?>"
												data-place-id="<?= $place_id; ?>"
												data-status="pending">
												<i class="fa fa-toggle-off" aria-hidden="true"></i>
											</a>
										</span>
										<?php
									}
									else {
										?>
										<span data-toggle="tooltip"	title="<?= $txt_toggle_approved; ?>">
											<a href="#" class="btn btn-green btn-less-padding approve-place"
												id="status-place-<?= $place_id; ?>"
												data-place-id="<?= $place_id; ?>"
												data-status="approved">
												<i class="fa fa-toggle-on" aria-hidden="true"></i>
											</a>
										</span>
										<?php
									}
									?>

									<!-- paid btn -->
									<?php
									if($paid == 0) {
										?>
										<span data-toggle="tooltip"	title="<?= $txt_toggle_paid; ?>">
											<a href="#" class="btn btn-default btn-less-padding paid-place"
												id="paid-place-<?= $place_id; ?>"
												data-place-id="<?= $place_id; ?>"
												data-paid="unpaid">
												&nbsp;<i class="fa fa-usd" aria-hidden="true"></i>&nbsp;
											</a>
										</span>
										<?php
									}
									else {
										?>
										<span data-toggle="tooltip"	title="<?= $txt_toggle_paid; ?>">
											<a href="#" class="btn btn-green btn-less-padding paid-place"
												id="paid-place-<?= $place_id; ?>"
												data-place-id="<?= $place_id; ?>"
												data-paid="paid">
												&nbsp;<i class="fa fa-usd" aria-hidden="true"></i>&nbsp;
											</a>
										</span>
										<?php
									}
									?>

									<!-- featured_home toggle -->
									<?php
									if($feat_home == 0) {
										?>
										<span data-toggle="tooltip"	title="<?= $txt_toggle_featured; ?>">
											<a href="#" class="btn btn-default btn-less-padding featured-home"
												id="featured-home-<?= $place_id; ?>"
												data-place-id="<?= $place_id; ?>"
												data-featured-home="not_featured">
												&nbsp;<i class="fa fa-home" aria-hidden="true"></i>&nbsp;
											</a>
										</span>
										<?php
									}
									else {
										?>
										<span data-toggle="tooltip"	title="<?= $txt_toggle_featured; ?>">
											<a href="#" class="btn btn-green btn-less-padding featured-home"
												id="featured-home-<?= $place_id; ?>"
												data-place-id="<?= $place_id; ?>"
												data-featured-home="featured">
												&nbsp;<i class="fa fa-home" aria-hidden="true"></i>&nbsp;
											</a>
										</span>
										<?php
									}
									?>

									<!-- edit btn -->
									<span data-toggle="tooltip"	title="<?= $txt_edit_place; ?>">
										<a href="<?= $baseurl; ?>/user/edit-place/<?= $place_id; ?>"
											class="btn btn-default btn-less-padding edit-place"
											data-id="<?= $place_id; ?>">
											&nbsp;<i class="fa fa-pencil" aria-hidden="true"></i>&nbsp;
										</a>
									</span>

									<!-- remove btn -->
									<span data-toggle="tooltip"	title="<?= $txt_remove_place; ?>">
										<a href="#" class="btn btn-default btn-less-padding"
											data-toggle="modal"
											data-target="#remove-place-modal"
											data-place-id="<?= $place_id; ?>">
											&nbsp;<i class="fa fa-trash" aria-hidden="true"></i>&nbsp;
										</a>
									</span>
								</td>
							</tr>
							<?php
						}
						?>
					</table>
				</div>

				<nav>
					<ul class="pagination">
						<?php
						if(isset($pager) && $pager->getTotalPages() > 1) {
							$curPage = $page;

							$startPage = ($curPage < 5)? 1 : $curPage - 4;
							$endPage = 8 + $startPage;
							$endPage = ($pager->getTotalPages() < $endPage) ? $pager->getTotalPages() : $endPage;
							$diff = $startPage - $endPage + 8;
							$startPage -= ($startPage - $diff > 0) ? $diff : 0;

							$startPage = ($startPage == 1) ? 2 : $startPage;
							$endPage = ($endPage == $pager->getTotalPages()) ? $endPage - 1 : $endPage;

							if($total_rows > 0) {
								$page_url = "$baseurl/admin/admin-listings/$sort/page/";

								if ($curPage > 1) {
									?>
									<li><a href="<?= $page_url; ?>1"><?= $txt_pager_page1; ?></a></li>
									<?php
								}
								if ($curPage > 6) {
									?>
									<li><span>...</span></li>
									<?php
								}
								if ($curPage == 1) {
									?>
									<li class="active"><span><?= $txt_pager_page1; ?></span></li>
									<?php
								}
								for($i = $startPage; $i <= $endPage; $i++) {
									if($i == $page) {
										?>
										<li class="active"><span><?= $i; ?></span></li>
										<?php
									}
									else {
										?>
										<li><a href="<?php echo $page_url, $i; ?>"><?= $i; ?></a></li>
										<?php
									}
								}

								if($curPage + 5 < $pager->getTotalPages()) {
									?>
									<li><span>...</span></li>
									<?php
								}
								if($pager->getTotalPages() > 5) {
									$last_page_txt = $txt_pager_last_page;
								}

								$last_page_txt = ($pager->getTotalPages() > 5) ? $txt_pager_last_page : $pager->getTotalPages();

								if($curPage == $pager->getTotalPages()) {
									?>
									<li class="active"><span><?= $last_page_txt; ?></span></li>
									<?php
								}
								else {
									?>
									<li><a href="<?php echo $page_url, $pager->getTotalPages(); ?>"><?= $last_page_txt; ?></a></li>
									<?php
								}
							} //  end if($total_rows > 0)
						} //  end if(isset($pager) && $pager->getTotalPages() > 1)
						if(isset($pager) && $pager->getTotalPages() == 1) {
							?>

							<?php
						}
						?>
					</ul>
				</nav>
			<?php
			} // end if($total_rows > 0)
			else {
				?>
				<?= $txt_no_results; ?>
				<?php
			}
			?>

	</div><!-- .padding -->
	</div><!-- .main-container -->
	<div class="clear"></div>
</div><!-- .wrapper -->
<?php require_once(__DIR__ . '/_admin_footer.php'); ?>

<!-- Remove Place Modal -->
<div class="modal fade" id="remove-place-modal" tabindex="-1" role="dialog" aria-labelledby="Remove Place Modal">
	<div class="modal-dialog" role="document">
		<div class="modal-content">
			<div class="modal-header">
				<button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
				<h4 class="modal-title" id="myModalLabel"><?= $txt_remove_place; ?></h4>
			</div>
			<div class="modal-body">

			</div>
			<div class="modal-footer">
				<button type="button" class="btn btn-default btn-less-padding" data-dismiss="modal"><?= $txt_cancel; ?></button>
				<button type="button" class="btn btn-blue btn-less-padding remove-place" data-dismiss="modal" data-remove-id><?= $txt_remove_place; ?></button>
			</div>
		</div>
	</div>
</div>

<script>
$(document).ready(function(){
	// search by place id
	$('#submit_place_id').click(function() {
		var place_id = $('#place_id').val();
		window.location.href = '<?= $baseurl; ?>/admin/admin-listings/find/' + place_id;
	});

	// show remove place modal
	$('#remove-place-modal').on('show.bs.modal', function(event) {
		var button = $(event.relatedTarget); // Button that triggered the modal
		var place_id = button.data('place-id'); // Extract info from data-* attributes
		var modal = $(this);

		// If necessary, you could initiate an AJAX request here (and then do the updating in a callback).
		var post_url = '<?= $baseurl; ?>' + '/admin/admin-get-place.php';

		$.post(post_url, { place_id: place_id },
			function(data) {
				modal.find('.modal-body').html(data).fadeIn();
				modal.find('.remove-place').attr('data-remove-id', place_id);
			}
		);
	});

	// remove place button in modal clicked
    $('.remove-place').click(function(){
		event.preventDefault();
		var modal = $('#remove-place-modal');
		var post_url = '<?= $baseurl; ?>' + '/admin/admin-process-remove-place.php';
		var button = $('.remove-place'); // Button that was clicked
		var place_id = button.data('remove-id');
		var var_test = button.data('test');

		$.post(post_url, { place_id: place_id },
			function(data) {
				modal.find('.modal-body').empty();
				modal.find('.modal-body').html(data).fadeIn();
			}
		);
    });

	// after removing and clicking the close button on the modal, reload
	$('#remove-place-modal').on('hide.bs.modal', function (event) {
		location.reload(true);
	});

	// toggle place status
	$('.approve-place').click(function() {
		event.preventDefault();
		var place_id = $(this).data('place-id');
		var post_url = '<?= $baseurl; ?>' + '/admin/admin-process-approve-place.php';
		var status = $(this).data('status');

		$.post(post_url, {
			place_id: place_id,
			status: status
			},
			function(data) {
				if(data == 'approved') {
					$('#status-place-' + place_id).removeClass('btn-default');
					$('#status-place-' + place_id).addClass('btn-green');
					$('#status-place-' + place_id + ' i').removeClass('fa-toggle-off');
					$('#status-place-' + place_id + ' i').addClass('fa-toggle-on');
					$('#status-place-' + place_id).data('status', 'approved');
				}
				if(data == 'pending') {
					$('#status-place-' + place_id).removeClass('btn-green');
					$('#status-place-' + place_id).addClass('btn-default');
					$('#status-place-' + place_id + ' i').removeClass('fa-toggle-on');
					$('#status-place-' + place_id + ' i').addClass('fa-toggle-off');
					$('#status-place-' + place_id).data('status', 'pending');
				}
			}
		);
	});

	// paid place switch
	$('.paid-place').click(function() {
		event.preventDefault();
		var place_id = $(this).data('place-id');
		var paid = $(this).data('paid');
		var post_url = '<?= $baseurl; ?>' + '/admin/admin-process-toggle-paid.php';

		$.post(post_url, {
			place_id: place_id,
			paid: paid
			},
			function(data) {
				if(data == 'unpaid') {
					$('#paid-place-' + place_id).removeClass('btn-green');
					$('#paid-place-' + place_id).addClass('btn-default');
					$('#paid-place-' + place_id).data('paid', 'unpaid');
				}
				if(data == 'paid') {
					$('#paid-place-' + place_id).removeClass('btn-default');
					$('#paid-place-' + place_id).addClass('btn-green');
					$('#paid-place-' + place_id).data('paid', 'paid');
				}
			}
		);
	});

	// featured home switch
	$('.featured-home').click(function() {
		event.preventDefault();
		var place_id = $(this).data('place-id');
		var featured_home = $(this).data('featured-home');
		var post_url = '<?= $baseurl; ?>' + '/admin/admin-process-toggle-featured-home.php';

		$.post(post_url, {
			place_id: place_id,
			featured_home: featured_home
			},
			function(data) {
				if(data == 'not_featured') {
					$('#featured-home-' + place_id).removeClass('btn-green');
					$('#featured-home-' + place_id).addClass('btn-default');
					$('#featured-home-' + place_id).data('featured-home', 'not_featured');
				}
				if(data == 'featured') {
					$('#featured-home-' + place_id).removeClass('btn-default');
					$('#featured-home-' + place_id).addClass('btn-green');
					$('#featured-home-' + place_id).data('featured-home', 'featured');
				}
			}
		);
	});

});
</script>
</body>
</html>